@@ -1,7 +1,7 @@
 CREATE TABLE classified (
  classified_id %%INCREMENT%%,
  posted_on     datetime not null, 
- posted_by     %%INCREMENT_TYPE%% not null,
+ posted_by     %%USERID_TYPE%% not null,
  title         varchar(50) null,
  organization  varchar(75) null,
  deadline      date null,
