@@ -1,7 +1,7 @@
 CREATE TABLE news (
  news_id       %%INCREMENT%%,
  posted_on     datetime not null, 
- posted_by     %%INCREMENT_TYPE%% not null,
+ posted_by     %%USERID_TYPE%% not null,
  title         varchar(75) null,
  news_item     text null,
  section       varchar(20) default 'Public',
