@@ -4,12 +4,12 @@ CREATE TABLE sys_user (
  password      varchar(30) not null,
  last_login    datetime null,
  num_logins    int null,
- theme_id      int null default 1,
+ theme_id      %%INCREMENT_TYPE%% default 1,
  first_name    varchar(50) null,
  last_name     varchar(50) null,
  title         varchar(50) null,
  email         varchar(100) not null,
- language      char(2) null default 'en',
+ language      char(2) default 'en',
  notes         text null,
  removal_date  datetime null,
  primary key   ( user_id ),
